@@ -1,5 +1,5 @@
 """Main module."""
-import pandas as pd
+
 from quica.dataset.dataset import IRRDataset
 from quica.measures.irr import *
 import pandas as pd
@@ -25,20 +25,23 @@ class Quica:
         return df.to_latex()
 
     def get_results(self):
-        measures = [Krippendorff(), FleissK(), ScottsPI()]
-        names = ["krippendorff", "fleiss", "scotts"]
+        measures = [Krippendorff(), ScottsPI(), RawAgreement(), MaceIRR()]
+        names = ["Krippendorff's Alpha", "Scotts' Kappa", "Raw Agreement", "MACE"]
 
         if self.dataset.coders == 2:
             measures.append(CohensK())
-            names.append("cohen")
+            names.append("Cohen's K")
+        else:
+            measures.append(FleissK())
+            names.append("Fleiss'K")
 
         results = []
         for measure in measures:
             results.append(measure.compute_irr(self.dataset))
 
-        data = pd.DataFrame({"names": names, "score": results})
-        data.index = data["names"]
-        del data["names"]
+        data = pd.DataFrame({"measure": names, "score": results})
+        data.index = data["measure"]
+        del data["measure"]
         return data
 
 
